
/* Generated data (by glib-mkenums) */

#ifndef __WNCK_ENUM_TYPES_H__
#define __WNCK_ENUM_TYPES_H__

/* enumerations from "window.h" */

GType wnck_window_state_get_type (void);
#define WNCK_TYPE_WINDOW_STATE (wnck_window_state_get_type())

GType wnck_window_actions_get_type (void);
#define WNCK_TYPE_WINDOW_ACTIONS (wnck_window_actions_get_type())

#endif /* __WNCK_ENUM_TYPES_H__ */

/* Generated data ends here */

